@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
 <context>
     <name>AirplaneModeItem</name>
     <message>
@@ -39,7 +37,7 @@
     <name>BluetoothAdapterItem</name>
     <message>
         <source>My Devices</source>
-        <translation type="unfinished"></translation>
+        <translation>Mis dispositivos</translation>
     </message>
 </context>
 <context>
@@ -54,7 +52,7 @@
     </message>
     <message>
         <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactive primero el modo avión si desea conectarse a un Bluetooth</translation>
     </message>
 </context>
 <context>
@@ -85,7 +83,7 @@
     </message>
     <message>
         <source>Turned off</source>
-        <translation>Apagado</translation>
+        <translation>Desactivado</translation>
     </message>
     <message>
         <source>Connected %1</source>
@@ -136,31 +134,31 @@
     <name>CWeekWidget</name>
     <message>
         <source>Sun</source>
-        <translation>Sun</translation>
+        <translation>dom.</translation>
     </message>
     <message>
         <source>Mon</source>
-        <translation>Mon</translation>
+        <translation>lun.</translation>
     </message>
     <message>
         <source>Tue</source>
-        <translation>Tue</translation>
+        <translation>mar.</translation>
     </message>
     <message>
         <source>Wed</source>
-        <translation>Wed</translation>
+        <translation>miérc.</translation>
     </message>
     <message>
         <source>Thu</source>
-        <translation>Thu</translation>
+        <translation>juev.</translation>
     </message>
     <message>
         <source>Fri</source>
-        <translation>Fri</translation>
+        <translation>vier.</translation>
     </message>
     <message>
         <source>Sat</source>
-        <translation>Sat</translation>
+        <translation>sáb.</translation>
     </message>
 </context>
 <context>
@@ -190,38 +188,38 @@
     </message>
     <message>
         <source>Open the calendar</source>
-        <translation type="unfinished"></translation>
+        <translation>Abrir el calendario</translation>
     </message>
 </context>
 <context>
     <name>DatetimeWidget</name>
     <message>
         <source>Monday</source>
-        <translation>Lunes</translation>
+        <translation>lunes</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation>Martes</translation>
+        <translation>martes</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation>Miércoles</translation>
+        <translation>miércoles</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation>Jueves</translation>
+        <translation>jueves</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation>Viernes</translation>
+        <translation>viernes</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation>Sábado</translation>
+        <translation>sábado</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>Domingo</translation>
+        <translation>domingo</translation>
     </message>
     <message>
         <source>monday</source>
@@ -256,7 +254,7 @@
     <name>DeviceControlWidget</name>
     <message>
         <source>Other Devices</source>
-        <translation type="unfinished"></translation>
+        <translation>Otros dispositivos</translation>
     </message>
 </context>
 <context>
@@ -309,82 +307,82 @@
     </message>
     <message>
         <source>Display settings</source>
-        <translation type="unfinished">Ajustes de Pantalla</translation>
+        <translation>Ajustes de Pantalla</translation>
     </message>
     <message>
         <source>Eye comfort</source>
-        <translation type="unfinished"></translation>
+        <translation>Descanso visual</translation>
     </message>
     <message>
         <source>Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Tema</translation>
     </message>
     <message>
         <source>On</source>
-        <translation type="unfinished"></translation>
+        <translation>Encendido</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished">Apagado</translation>
+        <translation>Apagado</translation>
     </message>
     <message>
         <source>Light</source>
-        <translation type="unfinished"></translation>
+        <translation>Claro</translation>
     </message>
     <message>
         <source>Dark</source>
-        <translation type="unfinished"></translation>
+        <translation>Oscuro</translation>
     </message>
     <message>
         <source>Auto</source>
-        <translation type="unfinished"></translation>
+        <translation>Automático</translation>
     </message>
     <message>
         <source>Disable eye comfort</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactivar el descanso visual</translation>
     </message>
     <message>
         <source>Enable eye comfort</source>
-        <translation type="unfinished"></translation>
+        <translation>Activar el descanso visual</translation>
     </message>
     <message>
         <source>Display Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajustes de pantalla</translation>
     </message>
     <message>
         <source>Theme: Light</source>
-        <translation type="unfinished"></translation>
+        <translation>Tema: Claro</translation>
     </message>
     <message>
         <source>Theme: Dark</source>
-        <translation type="unfinished"></translation>
+        <translation>Tema: Oscuro</translation>
     </message>
     <message>
         <source>Theme: Auto</source>
-        <translation type="unfinished"></translation>
+        <translation>Tema: Automatico</translation>
     </message>
     <message>
         <source>Visual effect</source>
-        <translation type="unfinished"></translation>
+        <translation>Efecto visual</translation>
     </message>
 </context>
 <context>
     <name>EyeComfortmodeApplet</name>
     <message>
         <source>Light</source>
-        <translation type="unfinished"></translation>
+        <translation>Claro</translation>
     </message>
     <message>
         <source>Dark</source>
-        <translation type="unfinished"></translation>
+        <translation>Oscuro</translation>
     </message>
     <message>
         <source>Auto</source>
-        <translation type="unfinished"></translation>
+        <translation>Auto</translation>
     </message>
     <message>
         <source>Theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Tema</translation>
     </message>
 </context>
 <context>
@@ -446,27 +444,27 @@
     <name>NotificationPlugin</name>
     <message>
         <source>No messages</source>
-        <translation type="unfinished"></translation>
+        <translation>No hay mensajes</translation>
     </message>
     <message>
         <source>Notification settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Ajustes de notificaciones</translation>
     </message>
     <message>
         <source>Notifications</source>
-        <translation type="unfinished"></translation>
+        <translation>Notificaciones</translation>
     </message>
     <message>
         <source>Turn off DND mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Desactivar el modo DND</translation>
     </message>
     <message>
         <source>Turn on DND mode</source>
-        <translation type="unfinished"></translation>
+        <translation>Activar el modo DND</translation>
     </message>
     <message>
         <source>Notification</source>
-        <translation type="unfinished"></translation>
+        <translation>Notificaciones</translation>
     </message>
 </context>
 <context>
@@ -496,14 +494,14 @@
     </message>
     <message>
         <source>Balance Performance</source>
-        <translation type="unfinished"></translation>
+        <translation>Rendimiento equilibrado</translation>
     </message>
 </context>
 <context>
     <name>PowerApplet</name>
     <message>
         <source>Power</source>
-        <translation type="unfinished"></translation>
+        <translation>Energía</translation>
     </message>
 </context>
 <context>
@@ -554,58 +552,58 @@
     </message>
     <message>
         <source>Charging, calculating estimated charging time</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargando, calculando el tiempo de carga estimado</translation>
     </message>
     <message>
         <source>Calculating remaining usage time</source>
-        <translation type="unfinished"></translation>
+        <translation>Calcular el tiempo de uso restante</translation>
     </message>
     <message>
         <source>%1 min remaining</source>
-        <translation type="unfinished"></translation>
+        <translation>1% min restante</translation>
     </message>
     <message>
         <source>%1 hr %2 min remaining</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 hr %2 min restante</translation>
     </message>
     <message>
         <source>Not charging</source>
-        <translation type="unfinished"></translation>
+        <translation>No esta cargando</translation>
     </message>
     <message>
         <source>Fully charged</source>
-        <translation type="unfinished"></translation>
+        <translation>Carga llena</translation>
     </message>
     <message>
         <source>Charging, %1 min until full</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargando, %1 min para completarse</translation>
     </message>
     <message>
         <source>Charging, %1 hr %2 min until full</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargando, %1 hr %2 min hasta completarse</translation>
     </message>
     <message>
         <source>Capacity %1, %2 hr remaining</source>
-        <translation type="unfinished"></translation>
+        <translation>Capacidad %1, %2 hr restante</translation>
     </message>
     <message>
         <source>%1 hr remaining</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 hr restante</translation>
     </message>
     <message>
         <source>Charging %1, %2 hr until full</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargando %1, %2 hr hasta completarse</translation>
     </message>
     <message>
         <source>Charging, %1 hr until full</source>
-        <translation type="unfinished"></translation>
+        <translation>Cargando, %1 hasta completarse</translation>
     </message>
 </context>
 <context>
     <name>PowerStatusWidget</name>
     <message>
         <source>Power settings</source>
-        <translation type="unfinished">Ajustes de energía</translation>
+        <translation>Ajustes de energía</translation>
     </message>
 </context>
 <context>
@@ -616,7 +614,7 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation type="unfinished"></translation>
+        <translation>Desconocido</translation>
     </message>
 </context>
 <context>
@@ -659,142 +657,142 @@
     </message>
     <message>
         <source>Shut Down</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar</translation>
     </message>
     <message>
         <source>Switch user</source>
-        <translation type="unfinished"></translation>
+        <translation>Cambiar usuario</translation>
     </message>
 </context>
 <context>
     <name>SidebarCalendarWidget</name>
     <message>
         <source>Today</source>
-        <translation type="unfinished"></translation>
+        <translation>Hoy</translation>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"></translation>
+        <translation>Lunar</translation>
     </message>
     <message>
         <source>y</source>
-        <translation type="unfinished"></translation>
+        <translation>a</translation>
     </message>
     <message>
         <source>m</source>
-        <translation type="unfinished"></translation>
+        <translation>m</translation>
     </message>
     <message>
         <source>d</source>
-        <translation type="unfinished"></translation>
+        <translation>d</translation>
     </message>
     <message>
         <source>Monday</source>
-        <translation type="unfinished">Lunes</translation>
+        <translation>Lunes</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation type="unfinished">Martes</translation>
+        <translation>Martes</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation type="unfinished">Miércoles</translation>
+        <translation>Miércoles</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation type="unfinished">Jueves</translation>
+        <translation>Jueves</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation type="unfinished">Viernes</translation>
+        <translation>Viernes</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation type="unfinished">Sábado</translation>
+        <translation>Sábado</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation type="unfinished">Domingo</translation>
+        <translation>Domingo</translation>
     </message>
     <message>
         <source>Jan</source>
-        <translation type="unfinished"></translation>
+        <translation>Ene</translation>
     </message>
     <message>
         <source>Feb</source>
-        <translation type="unfinished"></translation>
+        <translation>Feb</translation>
     </message>
     <message>
         <source>Mar</source>
-        <translation type="unfinished"></translation>
+        <translation>Mar</translation>
     </message>
     <message>
         <source>Apr</source>
-        <translation type="unfinished"></translation>
+        <translation>Abr</translation>
     </message>
     <message>
         <source>May</source>
-        <translation type="unfinished"></translation>
+        <translation>May</translation>
     </message>
     <message>
         <source>Jun</source>
-        <translation type="unfinished"></translation>
+        <translation>Jun</translation>
     </message>
     <message>
         <source>Jul</source>
-        <translation type="unfinished"></translation>
+        <translation>Jul</translation>
     </message>
     <message>
         <source>Aug</source>
-        <translation type="unfinished"></translation>
+        <translation>Ago</translation>
     </message>
     <message>
         <source>Sept</source>
-        <translation type="unfinished"></translation>
+        <translation>Sep</translation>
     </message>
     <message>
         <source>Oct</source>
-        <translation type="unfinished"></translation>
+        <translation>Oct</translation>
     </message>
     <message>
         <source>Nov</source>
-        <translation type="unfinished"></translation>
+        <translation>Nov</translation>
     </message>
     <message>
         <source>Dec</source>
-        <translation type="unfinished"></translation>
+        <translation>Dic</translation>
     </message>
     <message>
         <source>Open the calendar</source>
-        <translation type="unfinished"></translation>
+        <translation>Abrir el calendario</translation>
     </message>
     <message>
         <source>monday</source>
-        <translation type="unfinished">lunes</translation>
+        <translation>lunes</translation>
     </message>
     <message>
         <source>tuesday</source>
-        <translation type="unfinished">martes</translation>
+        <translation>martes</translation>
     </message>
     <message>
         <source>wednesday</source>
-        <translation type="unfinished">miércoles</translation>
+        <translation>miércoles</translation>
     </message>
     <message>
         <source>thursday</source>
-        <translation type="unfinished">jueves</translation>
+        <translation>jueves</translation>
     </message>
     <message>
         <source>friday</source>
-        <translation type="unfinished">viernes</translation>
+        <translation>viernes</translation>
     </message>
     <message>
         <source>saturday</source>
-        <translation type="unfinished">sábado</translation>
+        <translation>sábado</translation>
     </message>
     <message>
         <source>sunday</source>
-        <translation type="unfinished">domingo</translation>
+        <translation>domingo</translation>
     </message>
 </context>
 <context>
@@ -842,4 +840,4 @@
         <translation>Volumen %1</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
