@@ -1,15 +1,23 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="zh_CN">
+<context>
+    <name>PluginItem</name>
+    <message>
+        <location filename="../pluginitem.cpp" line="89"/>
+        <source>Remove from dock</source>
+        <translation>从任务栏移除</translation>
+    </message>
+</context>
 <context>
     <name>QuickPluginItem</name>
     <message>
-        <location filename="../quickpluginitem.cpp" line="120"/>
+        <location filename="../quickpluginitem.cpp" line="160"/>
         <source>Remove from dock</source>
         <translation>从任务栏移除</translation>
     </message>
     <message>
-        <location filename="../quickpluginitem.cpp" line="120"/>
+        <location filename="../quickpluginitem.cpp" line="160"/>
         <source>Pin to dock</source>
         <translation>固定到任务栏</translation>
     </message>
